<?php

use Zen\Payment\Notification;
use Zen\Payment\Util;

require_once 'ZenHelper.php';
require_once 'src/Notification.php';
require_once 'src/Util.php';
require_once 'src/Validate.php';
require_once 'vendor/autoload.php';

class ZenIpn
{

    const OS_PENDING = '1';
    const OS_PROCESSING = '2';

    public function notification()
    {

        $notification = new Notification(
            MODULE_PAYMENT_ZEN_IPN_SECRET
        );

        $resultCheckRequestNotification = $notification->checkRequest();

        if (is_int($resultCheckRequestNotification)) {

            echo Notification::formatResponse(Notification::NS_ERROR);
            exit;
        }

        $order = ZenHelper::getOrderById(
            Util::extractMerchantTransactionId($resultCheckRequestNotification['merchantTransactionId'])
        );
        $currencyValue = (float)$order['currency_value'];
        $orderTotal = ZenHelper::getOrderTotalById(
            Util::extractMerchantTransactionId($resultCheckRequestNotification['merchantTransactionId'])
        );

        if (!$order) {
            echo Notification::formatResponse(Notification::NS_ERROR);
            exit;
        }

        switch ($resultCheckRequestNotification['status']) {
            case Notification::STATUS_ACCEPTED:
                $notificationTransactionStatus = MODULE_PAYMENT_ZEN_PAID_STATUS_ID;
                break;
            case Notification::STATUS_REJECTED:
                $notificationTransactionStatus = MODULE_PAYMENT_ZEN_UNPAID_STATUS_ID;
                break;
            default:
                echo Notification::formatResponse(Notification::NS_OK);
                exit;
        }

        if ($order['orders_status'] !== self::OS_PENDING) {

            echo Notification::formatResponse(Notification::NS_ERROR);
            exit;
        }

        if (!$notification::checkRequestAmount($resultCheckRequestNotification, round($orderTotal * $currencyValue, 2), $order['currency'])) {

            echo Notification::formatResponse(Notification::NS_ERROR);
            exit;
        }

        ZenHelper::updateOrderStatus($resultCheckRequestNotification['merchantTransactionId'], $notificationTransactionStatus, $resultCheckRequestNotification['transactionId']);
        ZenHelper::addTransactionConfirmation($resultCheckRequestNotification['merchantTransactionId'], $resultCheckRequestNotification['transactionId']);

        echo Notification::formatResponse(Notification::NS_OK);
        exit;
    }

}
